@@ -1,9 +1,9 @@
 """
-django-vintage
+An archiver of web pages. Like a specialized django-flatpages.
 """
 __version_info__ = {
     'major': 0,
-    'minor': 1,
+    'minor': 2,
     'micro': 0,
     'releaselevel': 'final',
     'serial': 1
